@@ -1,5 +1,5 @@
 /*
- * ampr-ripd.c - AMPR 44net RIPv2 Listner Version 2.3
+ * ampr-ripd.c - AMPR 44net RIPv2 Listner Version 2.4
  *
  * Author: Marius Petrescu, YO2LOJ, <marius@yo2loj.ro>
  *
@@ -108,6 +108,9 @@
  *    2.1.1   29.May.2017    Corrected a tunnel interface detection error
  *    2.2     30.May.2017    Enable sending of call@locator to my server for dynamic map creation
  *    2.3      4.Jun.2017    Force the use of tunnel address as source IP on call home
+ *    2.4     15.Aug.2017    Corrected a segfault in NL handling on some systems (Tnx. Steve, VK5ASF & Bent, OZ6BL)
+ *                           Corrected a segfault on SIGHUP if call home not set (Tnx. Steve, VK5ASF & Bent, OZ6BL)
+ *                           Improved command line handling
  */
 
 #include <stdlib.h>
@@ -134,7 +137,7 @@
 #include <time.h>
 #include <ctype.h>
 
-#define AMPR_RIPD_VERSION	"2.3"
+#define AMPR_RIPD_VERSION	"2.4"
 
 #define RTSIZE		1000	/* maximum number of route entries */
 #define EXPTIME		600	/* route expiration in seconds */
@@ -1029,6 +1032,7 @@ void nl_debug(void *msg, int len)
 		    }
 		}
 	    }
+	    if (0 == (rh->nlmsg_flags & NLM_F_MULTI)) break;
 	}
     }
 }
@@ -1195,6 +1199,7 @@ uint32_t route_func(rt_actions action, uint32_t address, uint32_t netmask, uint3
 		{
 		    result = 0;
 		}
+		if (0 == (rh->nlmsg_flags & NLM_F_MULTI)) break;
 	    }
 	}
 
@@ -1218,6 +1223,7 @@ uint32_t route_func(rt_actions action, uint32_t address, uint32_t netmask, uint3
 		{
 		    result = 0;
 		}
+		if (0 == (rh->nlmsg_flags & NLM_F_MULTI)) break;
 	    }
 	}
     }
@@ -1856,9 +1862,12 @@ static void on_hup(int sig)
 #ifdef HAVE_DEBUG
 	if (debug) fprintf(stderr, "SIGHUP received!\n");
 #endif
-	hometimer = HOME_REPETITION;
-	if (debug) fprintf(stderr, "Calling home\n");
-	callhome(TRUE);
+	if (homedata)
+	{
+	    hometimer = HOME_REPETITION;
+	    if (debug) fprintf(stderr, "Calling home\n");
+	    callhome(TRUE);
+	}
 
 	route_delete_all();
 	list_clear();
@@ -1879,6 +1888,25 @@ int main(int argc, char **argv)
 
 	while ((p = getopt(argc, argv, "dvsrh?i:a:p:t:m:w:f:e:F:E:x:g:L:")) != -1)
 	{
+		switch (p)
+		{
+		    case 'd':
+		    case 'v':
+		    case 's':
+		    case 'r':
+		    case ':':
+		    case 'h':
+		    case '?':
+			break;
+		    default:
+			if (optarg && optarg[0] == '-')
+			{
+			    fprintf(stderr, "ampr-ripd: option -%c needs an argument.\n", p);
+			    return 1;
+			}
+			break;
+		}
+
 		switch (p)
 		{
 		case 'd':
